#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-5AeP2TzJe7CBSNWEF7sVoa
key:                  pipes-http-1.0.6-5AeP2TzJe7CBSNWEF7sVoa
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  1aab77ba76d010f23b12f7a4dae0d5b2
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-5AeP2TzJe7CBSNWEF7sVoa
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-client-0.7.19-KXZGeWCB42tHrklRoEfgGw
    http-client-tls-0.3.6.4-A4oTFfT0Noh4Qsq9wNW0bZ
    pipes-4.3.16-5IELyX2SNxA6WcDlpUhvr2

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

